#
# spec file for package perses-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name percli

Name:           perses-cli
Version:        0.50.1
Release:        1.1
Summary:        CLI for the Perses observability visualisation project
License:        Apache-2.0
URL:            https://github.com/perses/perses
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go1.23
BuildRequires:  zsh
Provides:       percli = %{version}

%description
Perses, a Cloud Native Computing Foundation sandbox project, is a dashboard
tool to visualize observability data from Prometheus/Thanos/Jaeger.

This package contains the CLI.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/prometheus/common/version.Version=%{version} \
   -X github.com/prometheus/common/version.Commit=${COMMIT_HASH} \
   -X github.com/prometheus/common/version.Branch=main \
   -X github.com/prometheus/common/version.BuildDate=${BUILD_DATE}" \
   -o bin/%{executable_name} ./cmd/%{executable_name}

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Fri Jan 24 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.50.1:
  * Merge pull request #2584 from perses/nexucis/release
  * [IGNORE] CI: e2e: bump actions/upload-artifact to v4 (#2564)
  * [FEATURE] Label metrics in stat chart (#2574)
  * [BUGFIX] Inject API prefix in all UI assets (#2576)
  * [BUGFIX] Login from percli (method not allowed) (#2577)
  * [FEATURE] Value mapping settings for Status History and Stat
    Chart (#2462)
  * [IGNORE] Add error boundary around recent dashboard on home
    page (#2560)
  * [BUGFIX] ListVariable: fix autocomplete when 'All' is selected
    (#2554)
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.50.0:
  * Release v0.50.0 (#2553)
  * [BUGFIX] Update unit's migration (#2519)
  * [BUGFIX] GaugeChartPanel: fix empty state (#2548)
  * [BUGFIX] Fixes tooltip display in EDGE / IE (#2547)
  * [BUGFIX] Redirect to the desired page after login success
    (#2354)
  * [IGNORE] Correctly type useQuery fetch hooks error (#2546)
  * BUGFIX: `percli dac setup`: fix useless requirement of go CLI
    when using CUE (#2544)
  * Release v0.50.0-rc.1 (#2543)
  * [BUGFIX] DaC CUE SDK: Fix inconsistencies in mandatory vs
    optional attributes in dashboard lib (#2540)
  * [ENHANCEMENT] : percli plugin lint: improve the way to find the
    schema files (#2526)
  * [ENHANCEMENT] `percli dac diff`: add output + avoid early
    return when processing a directory (#2500)
  * [ENHANCEMENT] DaC CUE SDK: accurate constraints for duration
    attributes (#2525)
  * [ENHANCEMENT] DaC CUE SDK: add datasource param to the var
    group builder (#2524)
  * [BUGFIX] Fix preview display name with prefix (#2520)
  * [ENHANCEMENT] Use Perses logo for the app loader (#2518)
  * [BUGFIX] Fix for migration of decimal units (#2493)
  * [BUGFIX] Table panel: fix cell mapping for range condition
    (#2517)
  * [ENHANCEMENT] Table panel: editor text fields are debounced
    (#2470)
  * [DOC] Align plugin doc with the migration revamp (#2516)
  * Release v0.50.0-rc.0 (#2515)
  * [IGNORE] Upgrade to TypeScript 5.4 + upgrade eslint (#2513)
  * update go deps (#2512)
  * Bump the k8s-io group with 3 updates (#2508)
  * Downgrade TypeScript version to v5.3 + enforce return typing
    (#2504)
  * [IGNORE] Upgrade TypeScript to v5.4 (#2502)
  * [IGNORE] Enforce typing in eslint base config (#2499)
  * [IGNORE] Enforce typing for plugin-system package (#2494)
  * [IGNORE] Enforce typing for e2e package (#2498)
  * [IGNORE] Enforce typing for storybook package (#2497)
  * [IGNORE] Enforce typing for tempo-plugin package (#2496)
  * [IGNORE] Enforce typing for prometheus-plugin package (#2495)
  * [IGNORE] Enforce typing for panels-plugin package (#2491)
  * [IGNORE] Enforce typing for explore package (#2489)
  * [IGNORE] Enforce typing for internal-utils package (#2490)
  * [IGNORE] Enforce typing for dashboards package (#2488)
  * [ENHANCEMENT] Improve the migration (#2481)
  * Bump github.com/huandu/go-sqlbuilder from 1.32.0 to 1.33.1
    (#2477)
  * [IGNORE] Enforce typing for app package (#2487)
  * Bump github.com/labstack/echo/v4 from 4.12.0 to 4.13.0 (#2478)
  * Bump github.com/prometheus/common from 0.60.1 to 0.61.0 (#2476)
  * [DOC] Adjustments in CLI doc (#2480)
  * [IGNORE] Ignore more flaky links checks (#2486)
  * [IGNORE] Enforce typing for components package (#2485)
  * [BUGFIX] `dac diff`: fix output folder not found (#2484)
  * [ENHANCEMENT] Table: add default column sorting (#2482)
  * [IGNORE] Upgrade MUI to v6 (#2473)
  * [FEATURE] add plugin build command (#2471)
  * [ENHANCEMENT] Table panel: migrate custom column ordering via
    "organize" transformation (#2419)
  * [BUGFIX] Table: mapping with min range 0 not working (#2472)
  * [IGNORE] Replace some wrong usage of "chart" term by "panel"
    (#2468)
  * [IGNORE] CLI remove useless check for output flag (#2467)
  * [ENHANCEMENT] Add search in metric finder + new option for
    hiding panel (#2466)
  * [ENHANCEMENT] Add sparkline migration (#2463)
  * Bump perses/github-actions from 0.6.0 to 0.7.1 (#2434)
  * [ENHANCEMENT] CLI/DAC: return a success message after writing a
    diff files (#2464)
  * Update text migration (#2465)
  * Add yellow mapping from grafana (#2461)
  * [ENHANCEMENT] Table: add default column width setting (#2446)
  * [BUGFIX] Table: fix migration of joinByField transform (#2458)
  * [FEATURE] add plugin lint command (#2459)
  * [ENHANCEMENT] Prefix dashboard display name when using dac
    preview command (#2460)
  * [BUGFIX] Fix Panel JSON validation (#2456)
  * [ENHANCEMENT] Add piechart migration (#2449)
  * [ENHANCEMENT] Table: add column sorting (#2450)
  * [IGNORE] Add function type check on core package (#2447)
  * upgrade debian version in Dockerfiles (#2441)
  * [IGNORE] Upgrade react-table and react-virtuoso + remove some
    sx props leaks (#2445)
  * [ENHANCEMENT] Table: best-effort migration of
    fieldConfig.overrides to columnSettings (#2443)
  * [ENHANCEMENT] Add cell focus on hover (#2442)
  * [FEATURE] Status History panel (#2403)
  * [BUGFIX] Fix tree view broken when using prometheus built-in
    vars (#2405)
  * copy duration type from prometheus/common (#2440)
  * add @jgbernalp as maintainer of the perses org (#2438)
  * [ENHANCEMENT] Update kubebuilder validation (#2437)
  * Bump github.com/stretchr/testify from 1.9.0 to 1.10.0 (#2436)
  * Bump the k8s-io group with 3 updates (#2435)
  * [ENHANCEMENT] add kubebuilder annotations to all duration types
    (#2433)
  * [BUGFIX] TimeSeriesChart: fix migration for the format
    attribrute (#2432)
  * [ENHANCEMENT] RoleBinding prechecking if user and role exist
    has been removed (#2430)
  * [IGNORE] Add optional local prometheus and tempo to dev env
    (#2418)
  * [IGNORE] Bump CUE to latest release (#2423)
  * Bump github.com/zitadel/oidc/v3 from 3.32.1 to 3.33.1 (#2422)
  * [ENHANCEMENT] Refactor struct field names and add validation
    for duration fields (#2360)
  * [BUGFIX] PromQL Tree view: stop firing the parse query before
    the show button gets clicked (#2427)
  * Bump cuelang.org/go from 0.11.0-alpha.5 to 0.11.0-rc.1 (#2421)
  * [FEATURE] new CLI command for plugins development (#2410)
  * Bump golang.org/x/mod from 0.21.0 to 0.22.0 (#2411)
  * Bump golang.org/x/crypto from 0.28.0 to 0.29.0 (#2412)
  * Bump cuelang.org/go from 0.11.0-alpha.4 to 0.11.0-alpha.5
    (#2414)
  * [BUGFIX] Fix login command avoiding reusing previous config
    (#2416)
  * Bump github.com/huandu/go-sqlbuilder from 1.31.0 to 1.32.0
    (#2415)
  * Bump golang.org/x/oauth2 from 0.23.0 to 0.24.0 (#2413)
  * [FEATURE] Table panel: columns can be reordered (#2392)
  * [ENHANCEMENT] More user-friendly helpers for prometheus
    built-in variables (#2407)
  * [BUGFIX] Remove some SX props leaking (#2408)
  * [BUGFIX] Edit mode not working after clicking on the resource
    row (#2404)
  * Migrate defaultValue (#2406)
  * [IGNORE] small fix in DaC doc (#2402)
  * [IGNORE] Add some external variables to the dev data (#2088)
  * [IGNORE] fix remaining indentation issues for the doc website
    (#2400)
  * update contact list in github issue (#2398)
  * [DOC] Adjust markdown syntax following issues spotted on
    website (#2397)
- remove patch b04061023c941d879460d81e6e4c6019621dbc16.patch
* Tue Dec 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- backport patch b04061023c941d879460d81e6e4c6019621dbc16.patch to
  fix failing logins
  https://github.com/perses/perses/pull/2416
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.49.0:
  CLI-related changes:
  * [DOC] better wording for `percli dac`'s commands helpers
    (#2350)
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.48.0:
  https://github.com/perses/perses/releases/tag/v0.48.0
  CLI-related changes:
  * [DOC] Add links in the CLI doc (#2276)
  * [ENHANCEMENT] Ignore Not Found errors in percli delete command
    (#2184)
* Tue Sep 10 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package perses-cli: CLI for the Perses observability
  visualisation project
